pitchtools.NamedChromaticPitchClassSet
======================================

.. inheritance-diagram:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.inversion_equivalent_diatonic_interval_class_vector

.. autoattribute:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.named_chromatic_pitch_classes

.. autoattribute:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.numbered_chromatic_pitch_class_set

.. autoattribute:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.copy

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.difference

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.intersection

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.isdisjoint

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.issubset

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.issuperset

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.order_by

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.symmetric_difference

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.transpose

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.union

    Inherited from :py:class:`__builtin__.frozenset`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__and__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__cmp__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__contains__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__eq__

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__ge__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__gt__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__hash__

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__iter__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__le__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__len__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__lt__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__ne__

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__or__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__rand__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__repr__

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__ror__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__rsub__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__rxor__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__str__

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__sub__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.__xor__

    Inherited from :py:class:`__builtin__.frozenset`
